;UTIL.SC                                                                      --->
; 
; Procedures called by MIGHTY.SC and supporting procedures
; 
; (C) 1993 by Timothy J. Massey
; All Rights Reserved
;
; Portions copied from the book "Using Paradox 4 Special Edition"
;  by Walter R. Bruce III, published by Que.
;
;
; This script fills UTIL.LIB with the following procedures:
;       TitleScreen()
;	MainMenu()
;       MaxWindow()
;       GetCustID()
;	TameMemoBox()
;	ConfirmBox()
;	CheckPrinter()
;	AboutBox()
;	RepaintAboutBox()
;	ErrorBeep()
;       Shutdown()
;
; TitleScreen() draws the introductory screen
; MainMenu() creates the main menu
; MaxWindow() maximizes + removes the frame of any window
; GetCustID() pops up a dialog box for the user to type the cust. # info
; TameMemoBox() handles the editing of memo fields
; ConfirmBox() pops up a dialog box to confirm an action
; AboutBox() tells the user about the application
; RepaintAboutBox() refreshes the AboutBox() dialog box
; ErrorBeep() beeps at the user
; Shutdown() clears the desktop and memory, and then exits
;
; User procedures called:
;       FillOrder()	(INVOICE.LIB)
;	Shutdown()	(UTIL.LIB)

LibName=ScriptDir+"UTIL"        ; All procedures in this script are contained
                                ;  in UTIL.LIB

;***********************************************************************;
;                               TitleScreen()                           ;
; This procedure draws the opening window that contains copyright and   ;
; author information.                                                   ;
;***********************************************************************;

PROC TitleScreen()              ; Procedure to display opening screen
 PRIVATE WndSettings            ; Local variable definitions

 DYNARRAY WndSettings[]         ; Dynamic array for window settings
 WndSettings["HASFRAME"]=FALSE  ; No frame
 WndSettings["ORIGINROW"]=7
 WndSettings["ORIGINCOL"]=22    ; Top left coordinates are 7,22
 WndSettings["FLOATING"]=TRUE   ; The window floats to the top
 WndSettings["HEIGHT"]=10
 WndSettings["WIDTH"]=39        ; Window is 10x39 chars big
 
 WINDOW CREATE ATTRIBUTES WndSettings TO whndTitleWindow
                                ;Create new window with attributes stored in
                                ; in WndSettings and store its handle in
                                ; TitleWindow
                                
CURSOR OFF                      ; Turns off cursor
CANVAS OFF                      ; Turns off screen updating

                                ; Writes info in window...
@1,0 ?? FORMAT("W38,AC","Mighty Invoice Processing System")
@2,0 ?? FORMAT("W38,AC","By Timothy J. Massey")
@4,0 ?? FORMAT("W38,AC","(C)  Copyright 1994, 1995")
@5,0 ?? FORMAT("W38,AC","Timothy J. Massey")
@8,0 ?? FORMAT("W38,AC","Loading application...")

                                ; Color the entire window white on blue
PAINTCANVAS ATTRIBUTE 14+16 0,0,9,44
PAINTCANVAS ATTRIBUTE 7+16 2,0,2,44
PAINTCANVAS ATTRIBUTE 11+16 4,0,5,44
PAINTCANVAS ATTRIBUTE 15+16 8,0,8,44
PAINTCANVAS ATTRIBUTE 15+16+128 8,27,8,29

CANVAS ON                       ; Display changes

ENDPROC

WRITELIB LibName TitleScreen    ; Saves PROC TitleScreen in LIB
RELEASE PROCS TitleScreen       ; Releases PROC from memory


;**********************************************************************;
;                              PrinterInit()                           ;
; This procedure initializes the variables used reports to set such    ;
; things as compressed and double-wide printing.                       ;
;**********************************************************************;
PROC AppInit()

VIEW TableDir + "Config"
WINDOW HANDLE CURRENT TO TwhndConfig
ActivePrinter=[Active Printer]

WINDOW SELECT TwhndConfig
WINDOW CLOSE

SWITCH
   CASE ActivePrinter="1" :
      MESSAGE "Epson FX/LQ or Panasonic KX-P series in Epson mode"
      init="\027\116\001"
      comp_on="\015"
      comp_off="\018"
      pica="\027\080"
      double_on="\027\087\001"
      double_off="\027\087\000"

   CASE ActivePrinter="2" :
      MESSAGE "IBM Proprinter or Panasonic KX-P series in IBM Proprinter mode"
      init=""
      comp_on="\015"
      comp_off="\018"
      pica="\027\080"
      double_on="\027\087\001"
      double_off="\027\087\000"

   CASE ActivePrinter="3" :
      MESSAGE "C. Itoh"
      init=""
      comp_on="\027\081"
      comp_off="\027\078"
      pica="\027\078"
      double_on="\014"
      double_off="\015"

   OTHERWISE :
      MESSAGE "Error:  Unknown menu option!  Tell programmer this happened"
      SLEEP 5000
      Shutdown()

   ENDSWITCH

ENDPROC

WRITELIB LibName AppInit    ; Saves PROC TitleScreen in LIB
RELEASE PROCS AppInit       ; Releases PROC from memory


;**********************************************************************;
;                             ChangePrinter()                          ;
;**********************************************************************;
PROC ChangePrinter()

ChoicePrinter="NONE"

WHILE UPPER(ChoicePrinter)="NONE"
   SHOWMENU
      "Epson"		: "Printing using a printer in Epson Mode",
      "IBM Proprinter"	: "Printing using a printer in IBM Proprinter Mode",
      "C. Itoh"		: "Printing using C. Itoh"
   TO ChoicePrinter

   IF UPPER(ChoicePrinter) = "ESC" THEN           ; If user presses "ESC",
      RETURN False
   ENDIF
ENDWHILE

COEDIT "Config"
WINDOW HANDLE CURRENT TO TwhndConfig

SWITCH
   CASE ChoicePrinter="Epson" :
      [Config->Active Printer]="1"

   CASE ChoicePrinter="IBM Proprinter" :
      [Config->Active Printer]="2"

   CASE ChoicePrinter="C. Itoh" :
      [Config->Active Printer]="3"

   OTHERWISE :
      MESSAGE "Error:  Unknown menu option!  Tell programmer this happened"
      SLEEP 5000
      Shutdown()

ENDSWITCH

DO_IT!

ENDPROC

WRITELIB LibName ChangePrinter    ; Saves PROC TitleScreen in LIB
RELEASE PROCS ChangePrinter       ; Releases PROC from memory


;**********************************************************************;
;                                MainMenu()                            ;
; This procedure sets up the main menu and launches the neccessary     ;
; procedures depending on the choice made.                             ;
;**********************************************************************;
PROC MainMenu()
   PRIVATE MenuSelect           ; Local variable definitions

ALTSPACE {Desktop} {Empty}              ; Clear desktop

OldInvoice=FALSE
InvoiceAdd=FALSE
IF NOT ISEMPTY(TableDir+"Invoice") THEN
   NextInv=STRVAL(CMAX(TableDir+"Invoice","Invoice#")+1)
ELSE
   NextInv=10001
ENDIF

DYNARRAY MenuProcs[]
   MenuProcs["FillOrder"]=      "FillOrder"
   MenuProcs["EditOrder"]=      "EditOrder"
   MenuProcs["PostReceipt"]=	"PostReceipt"
   MenuProcs["Settlement"]=     "Settlement"
   MenuProcs["MenuTaxSheet"]=	"MenuTaxSheet"
   MenuProcs["AddCust"]=	"AddCust"
   MenuProcs["EditCust"]=       "EditCust"
   MenuProcs["DelCust"]=        "DelCust"
   MenuProcs["AddPart"]=        "AddPart"
   MenuProcs["EditPart"]=       "EditPart"
   MenuProcs["EditMessage"]=    "EditMessage"
   MenuProcs["CopyPriceList"]=  "CopyPriceList"
   MenuProcs["DelPart"]=        "DelPart"
   MenuProcs["CustBuyingPattern"]="CustBuyingPattern"
   MenuProcs["TotalGrossProfit"]="TotalGrossProfit"
   MenuProcs["SamePartChange"]="SamePartPrices"
   MenuProcs["PhoneList"]=	"PhoneList"
   MenuProcs["AddressList"]=	"AddressList"
   MenuProcs["MasterList"]=	"MasterList"
   MenuProcs["SetCommLevel"]=	"SetCommLevel"
   MenuProcs["ChangePrinter"]=	"ChangePrinter"
   MenuProcs["ClearPriceList"]=	"ClearPriceList"
   MenuProcs["MakeProposal"]=	"MakeProposal"
   MenuProcs["AddSalesman"]=	"AddSalesman"
   MenuProcs["UniqueDesc"]=	"UniqueDesc"
   MenuProcs["PartsList"]=	"PartsList"
   MenuProcs["EnterQty"]=	"EnterQty"
   MenuProcs["AboutBox"]=       "AboutBox"
   MenuProcs["Shutdown"]=       "Shutdown"

SHOWPOPUP "Main Menu" CENTERED  ; Creates main menu
;=====================================================================================;
;                    Structure of menu declaration is as follows:                     ; 
;=====================================================================================;
;  "Menu label"		: "Bottom line description"			: "ReturnVal" ;
;-------------------------------------------------------------------------------------;
   "Create ~I~nvoice #"+STRVAL(NextInv)	: "Produce a new invoice for a customer"	: "FillOrder",
   "Edit Invoice"       : "Recalls an existing invoice for editing"	: "EditOrder",
   "Paid on Account"	: "Post a payment by a customer"		: "PostReceipt",
   SEPARATOR,
   "Produce ~S~ettlement"	: "Generate a sales settlement sheet"		: "Settlement",
   "Produce ~T~ax Sheet"	: "Generate a list of taxes due to each state"	: "MenuTaxSheet",
   SEPARATOR,
   "Reports Menu"	: "View or print reports about your data"	: "ReportsMenu"
      SUBMENU
      "Print ~P~rice List"	: "Print a list of parts at a certain price"	: "MakeProposal",
      "Print ~D~epartments"	: "Prints a list of unique departments"	: "UniqueDesc",
      "Buying History"		: "Prints a list of a customer's past purchases"	: "CustBuyingPattern",
      "Parts List Gross Profit" : "Prints out the %GP for each part selected"   : "TotalGrossProfit",
      "Inventory Value"		: "Prices out the value of on-hand inventory"	: "ValueOfInventory"
      SUBMENU
         "Print P~a~rts List"	: "Print a list of all part numbers and prices"	: "PartsList",
         "Enter Quantity"	: "Enter a quantity for each part"		: "EnterQty"
      ENDSUBMENU,
      "Customer ~L~ists"	: "Address, phone, and master customer lists"	: "CustomerLists"
         SUBMENU
         "Phone List"	: "Prints a phone list by salesman"		: "PhoneList",
         "Address List"	: "Prints an address list by salesman"		: "AddressList",
         "Master List"	: "Prints a master list by salesman"		: "MasterList"
         ENDSUBMENU
      ENDSUBMENU,      
   "E~d~it Menu"		: "Edit customer, parts, or message data"	: "EditMenu"
      SUBMENU
      "Parts"		: "Add, edit or delete parts data"		: "Customer"
         SUBMENU
         "Edit"		: "Edit an existing part"			: "EditPart",
         "Add"		: "Add a part"					: "AddPart",
         "Delete"	: "Delete a part"				: "DelPart",
         "Group Change" : "Change a group of parts with the same price and description" : "SamePartChange"
         ENDSUBMENU,
      "Customers"	: "Add, edit or delete customer data"		: "Customer"
         SUBMENU
         "Edit"		: "Edit an existing customer"			: "EditCust",
         "Add"		: "Add a customer"				: "AddCust",
         "Delete"	: "Delete a customer"				: "DelCust"
         ENDSUBMENU
      ENDSUBMENU,
   SEPARATOR,
   "Options Menu"	: "Edit customer, parts, or message data"	: "OptionsMenu"
      SUBMENU
      "Edit ~C~ommissions"	: "Edit commission levels"			: "SetCommLevel",
      "Edit Invoice ~M~essages"	: "Edit the permament invoice messages"		: "EditMessage",
      "Copy ~P~rice List"	: "Copy a price list from one list to another"		: "CopyPriceList",
      "Clear Price ~L~ist"	: "Clear an existing price list"		: "ClearPriceList",
      "Add ~S~alesperson"	: "Add a newsalesperson code"			: "AddSalesman",
      "Change P~r~inter"        : "Change printer for reports"                  : "ChangePrinter"
      ENDSUBMENU,
   SEPARATOR,
   "About"		: "About the application"			: "AboutBox",
   "E~x~it"		: "Leave the application"			: "Exit"
      SUBMENU
      "No"		: "Stay here"					: "Stay",
      "Yes"		: "Leave the application"			: "Shutdown"
      ENDSUBMENU
ENDMENU
TO MenuSelect				; Stores menu choice in MenuSelect

IF MenuSelect = "Esc" THEN		; If user presses "ESC",
   IF ConfirmBox("Do you really want to exit?", "", "") = TRUE THEN
					;  confirm exit
      Shutdown()			; If user says yes, Shutdown,
   ENDIF				; else, ignore.
ENDIF

IF ISASSIGNED(MenuProcs[MenuSelect])    ; Launch proper procedure depending
   THEN EXECPROC MenuProcs[MenuSelect]  ; on choice
ENDIF

ENDPROC

WRITELIB LibName MainMenu               ; Write MainMenu to LIB
RELEASE PROCS MainMenu                  ; and release from memory


;***********************************************************************;
;                                MaxWindow()                            ;
; This procedure will maximize and remove the window frame of any       ;
; window who's window handle can be passed to it.                       ;
;***********************************************************************;
PROC MaxWindow(whndWindow)
   PRIVATE WinAttr

IF ISWINDOW(whndWindow)         ; Make sure window exists
   THEN DYNARRAY WinAttr[]
   WinAttr["MAXIMIZED"]=TRUE    ; Window is maximized
   WinAttr["HASFRAME"]=FALSE    ; No frame on window
   WinAttr["CANMOVE"]=FALSE     ; Window can't move
   WinAttr["CANRESIZE"]=FALSE   ; Can't resize. either
   WinAttr["CANCLOSE"]=FALSE    ; Can't close. also

   WINDOW SETATTRIBUTES whndWindow FROM WinAttr
ENDIF                           ; Change window attributes

RETURN ISWINDOW(whndWindow)     ; Returns FALSE if window doesn't exist

ENDPROC

WRITELIB libname MaxWindow
RELEASE PROCS MaxWindow


;***********************************************************************;
;                             SetCommLevel()                            ;
; This procedure allows the user to set the commission percentages for  ;
; salesman and parts.                                                   ;
;***********************************************************************;
PROC SetCommLevel()

VIEW TableDir + "Config"
WINDOW HANDLE CURRENT TO TwhndConfig
WINDOW MOVE TwhndConfig TO 1000,0
MOVETO [Config->CommLevel 0]

CommLevel1=[CommLevel 0]*100
CommLevel2=[CommLevel 1]*100
CommLevel3=[CommLevel 2]*100
CommLevel4=[CommLevel 3]*100
CommLevel5=[CommLevel 4]*100
CommLevelA=[CommLevel 5]*100
CommLevelB=[CommLevel 6]*100
CommLevelC=[CommLevel 7]*100
CommLevelD=[CommLevel 8]*100
CommLevelE=[CommLevel 9]*100

SHOWDIALOG "Commission Levels"
   @ 3,20 HEIGHT 17 WIDTH 40 

@ 1,3 ?? "Commission 1:"
ACCEPT @1,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "Commision1"
  TO CommLevel1

@ 2,14 ?? "2:"
ACCEPT @2,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "Commision2"
  TO CommLevel2

@ 3,14 ?? "3:"
ACCEPT @3,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "Commision3"
  TO CommLevel3

@ 4,14 ?? "4:"
ACCEPT @4,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "Commision4"
  TO CommLevel4

@ 5,14 ?? "5:"
ACCEPT @5,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "Commision5"
  TO CommLevel5

@ 7,14 ?? "A:"
ACCEPT @7,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "CommisionA"
  TO CommLevelA

@ 8,14 ?? "B:"
ACCEPT @8,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "CommisionB"
  TO CommLevelB

@ 9,14 ?? "C:"
ACCEPT @9,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "CommisionC"
  TO CommLevelC

@ 10,14 ?? "D:"
ACCEPT @10,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "CommisionD"
  TO CommLevelD

@ 11,14 ?? "E:"
ACCEPT @11,18 
  WIDTH 12
  "N"
  MIN 0
  MAX 100
  REQUIRED
  TAG "CommisionE"
  TO CommLevelE

PUSHBUTTON @ 13,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 13,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG

IF RetVal=FALSE THEN RETURN FALSE ENDIF

COEDITKEY

REPLACEFIELDS	[CommLevel 0]	CommLevel1/100,
		[CommLevel 1]	CommLevel2/100,
		[CommLevel 2]	CommLevel3/100,
		[CommLevel 3]	CommLevel4/100,
		[CommLevel 4]	CommLevel5/100,
		[CommLevel 5]	CommLevelA/100,
		[CommLevel 6]	CommLevelB/100,
		[CommLevel 7]	CommLevelC/100,
		[CommLevel 8]	CommLevelD/100,
		[CommLevel 9]	CommLevelE/100

DO_IT!
RETURN 0

ENDPROC

WRITELIB LibName SetCommLevel
RELEASE PROCS SetCommLevel


;***********************************************************************;
;                               GetCustID()                             ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an ID # int, an OK and a CANCEL buttons.                        ;
;***********************************************************************;
PROC GetCustID()
   PRIVATE CustID, ButtonVal    ; Local variable definiton

CustID=1001
SHOWDIALOG "Customer Number"
  PROC "CustIDDlgProc"
   @ 7,20 HEIGHT 9 WIDTH 40
                                ; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter customer #:"    ; Write label in box

ACCEPT @ 1,27 WIDTH 8           ; Create an ACCEPT element
 "N"                            ; Accept numeric
 LOOKUP TableDir + "CUSTOMER"   ; Valcheck with Customer table
 TAG "AcceptTag"                ; Unused
 TO CustID                      ; User's input put here

;PUSHBUTTON @3,10 WIDTH 16
; "View Options"
; VALUE 2
; TAG "ViewOptions"
; TO ButtonVal

PUSHBUTTON @ 5,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 5,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE
   ELSE RETURN CustID
ENDIF
                                ; Return the number typed if exists, else
                                ;  return FALSE

ENDPROC

WRITELIB LibName GetCustID      ; Writes procedure to UTIL.SC
RELEASE PROCS GetCustID         ;  and releases it from memory


;***********************************************************************;
;                              GetPartDesc()                            ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an ID # int, an OK and a CANCEL buttons.                        ;
;***********************************************************************;
PROC GetPartDesc()
   PRIVATE PartDesc, ButtonVal    ; Local variable definiton

PartDesc=""
SHOWDIALOG "Part Description"
   @ 7,20 HEIGHT 9 WIDTH 40
                                ; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter Part Desc.:"    ; Write label in box

ACCEPT @ 1,22 WIDTH 15           ; Create an ACCEPT element
 "A20"                            ; Accept numeric
 PICTURE "*!"
 TAG "AcceptTag"                ; Unused
 TO PartDesc                      ; User's input put here

PUSHBUTTON @3,10 WIDTH 16
 "All Parts"
 OK
 VALUE 2
 TAG "AllParts"
 TO ButtonVal

PUSHBUTTON @ 5,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 5,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE ENDIF
IF ButtonVal=1 THEN RETURN PartDesc ENDIF
IF ButtonVal=2 THEN RETURN "_NO PART!_"
ELSE RETURN FALSE ENDIF

                                ; Return the number typed if exists, else
                                ;  return FALSE

ENDPROC

WRITELIB LibName GetPartDesc      ; Writes procedure to UTIL.SC
RELEASE PROCS GetPartDesc         ;  and releases it from memory


;***********************************************************************;
;                             CustIDDlgPROC()                           ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an ID # int, an OK and a CANCEL buttons.                        ;
;***********************************************************************;
PROC CustIDDlgPROC(EventType, TagValue, EventValue, ElementValue)
SWITCH
   CASE EventType="UPDATE" AND TagValue="ViewOptions" :
      ViewCust()
   RETURN FALSE

   OTHERWISE : RETURN TRUE
ENDSWITCH

ENDPROC

WRITELIB LibName CustIDDlgPROC      ; Writes procedure to UTIL.SC
RELEASE PROCS CustIDDlgPROC         ;  and releases it from memory


;***********************************************************************;
;                                  ViewCust()                           ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an ID # int, an OK and a CANCEL buttons.                        ;
;***********************************************************************;
PROC ViewCust()

VIEW TableDir + "Customer"
WINDOW HANDLE CURRENT TO TwhndCustomer
WINDOW MOVE TwhndCustomer TO 1000,0

PICKFORM "3"
WINDOW HANDLE CURRENT TO FwhndCustomer

DYNARRAY WinAttr[]
   WinAttr["MAXIMIZED"]=FALSE   ; Window is maximized
   WinAttr["HASFRAME"]=FALSE	; No Frame on window
   WinAttr["CANMOVE"]=FALSE     ; Window can't move
   WinAttr["CANRESIZE"]=FALSE   ; Can't resize. either
   WinAttr["CANCLOSE"]=FALSE    ; Can't close. also
   WinAttr["FLOATING"]=TRUE	; Window floats on top
   WinAttr["HASSHADOW"]=TRUE	; Window has a shadow
   WinAttr["HEIGHT"]=10		; Window of height 10
   WinAttr["WIDTH"]=45		; Window of width 45

WINDOW SETATTRIBUTES FwhndCustomer FROM WinAttr
WINDOW MOVE FwhndCustomer TO 13,17

IMAGERIGHTS READONLY

ECHO NORMAL
ECHO OFF

WINDOW SELECT TwhndCustomer

WAIT WORKSPACE UNTIL "F2"

WINDOW SELECT FwhndCustomer
WINDOW CLOSE
WINDOW SELECT TwhndCustomer
WINDOW CLOSE

ECHO NORMAL
ECHO OFF

ENDPROC

WRITELIB LibName ViewCust         ; Writes procedure to UTIL.SC
RELEASE PROCS ViewCust            ;  and releases it from memory


;***********************************************************************;
;                             TameMemoBox()                             ;
; This procedure changes the attributes of a memo field window and      ;
; handles interaction by the user.                                      ;
;***********************************************************************;
PROC TameMemoBox(whndMemo)
   PRIVATE wAttrib

IF ISWINDOW(whndMemo)
   THEN DYNARRAY wAttrib[]
      wAttrib["TITLE"]=""
      wAttrib["ORIGINROW"]=7
      wAttrib["ORIGINCOL"]=16
      wAttrib["HEIGHT"]=10
      wAttrib["WIDTH"]=45
      wAttrib["CANCLOSE"]=FALSE

   WINDOW SETATTRIBUTES whndMemo FROM wAttrib
ENDIF

PROMPT "   [F2] Save Changes    [Esc] Cancel changes"
WHILE TRUE
   WAIT FIELD
   UNTIL "F2", "Esc", "DOS", "DOSBIG"
   SWITCH
      CASE RetVal = "F2" : DO_IT! QUITLOOP
      CASE RetVal = "Esc" : CANCELEDIT QUITLOOP
      OTHERWISE : LOOP
   ENDSWITCH
ENDWHILE

ENDPROC

WRITELIB LibName TameMemoBox
RELEASE PROCS TameMemoBox


;***********************************************************************;
;                              ConfirmBox()                             ;
; This procedure pops up a dialog box with "Yes" and "No" buttons to    ;
; confirm an action.                                                    ;
;***********************************************************************;
PROC ConfirmBox(QString, OriginRow, OriginCol)
   PRIVATE CButtonVal

OriginCol=IIF(OriginCol="",19,OriginCol)
OriginRow=IIF(OriginRow="",6,OriginRow)

SHOWDIALOG "Confirm"
 @ OriginRow,OriginCol
 HEIGHT 7 WIDTH 40

@1,0 ?? FORMAT("W38,AC",Qstring)

PUSHBUTTON @3,6 WIDTH 10
 "~Y~es"
 OK
 VALUE TRUE
 TAG "OKButton"
 TO CButtonVal

PUSHBUTTON @3,21 WIDTH 10
 "~N~o"
 CANCEL
 VALUE FALSE
 TAG "CancelButton"
 TO CButtonVal

ENDDIALOG

RETURN RetVal

ENDPROC

WRITELIB LibName ConfirmBox
RELEASE PROCS ConfirmBox


;***********************************************************************;
;                              CheckPrinter()                           ;
; This procedure checks to make sure that the printer is on and online. ;
; If it is not, it asks user to retry or cancel.                        ;
;***********************************************************************;
PROC CheckPrinter()
   PRIVATE MenuSelection

MESSAGE "Checking printer status..."

WHILE NOT PRINTERSTATUS()
   MESSAGE""
   WHILE TRUE
      SHOWPOPUP "Printer Offline" CENTERED
         "Retry"	: "Retry print job"	: "Retry",
         "Cancel"	: "Cancel print job"	: "Cancel"
      ENDMENU
      TO MenuSelection

      IF MenuSelection="Retry" THEN
         QUITLOOP
      ELSE
         MESSAGE ""
         RETURN FALSE
      ENDIF
   ENDWHILE
   MESSAGE "Checking printer status..."
ENDWHILE

MESSAGE ""
RETURN TRUE

ENDPROC

WRITELIB LibName CheckPrinter
RELEASE PROCS CheckPrinter


;***********************************************************************;
;                               AboutBox()                              ;
; This procedure tells the user information about the program and the   ;
; operating enviornment.                                                ;
;***********************************************************************;
PROC AboutBox()

SYSINFO TO InfoArray

SHOWDIALOG ""
 PROC "RepaintAboutBox"
 IDLE
 @3,17 HEIGHT 18 WIDTH 45

   PAINTCANVAS ATTRIBUTE 15+16 0,0,15,42

   STYLE ATTRIBUTE 14+16
   @1,0 ?? FORMAT("W43,AC", "Mighty Invoice Processing System v1.11")
   STYLE ATTRIBUTE 7+16
   @2,0 ?? FORMAT("W43,AC","(C) Copyright 1994, 1996")
   @3,0 ?? FORMAT("W43,AC","Timothy J. Massey")

   STYLE ATTRIBUTE 15+16
   @5,0 ?? FORMAT("W43,AC", "17440 Lebanon Rd.")
   @6,0 ?? FORMAT("W43,AC", "Ft. Myers, FL  33912")
   @7,0 ?? FORMAT("W43,AC", "tmassey@m-net.arbornet.org")
   @8,0 ?? FORMAT("W43,AC", "(941)481-9785")

   STYLE ATTRIBUTE 7+16
   @10,0 ?? FORMAT("W43,AC", FORMAT("D2", TODAY()) +  "   "+TIME())
   @11,0 ?? FORMAT("W43,AC","Mouse is"+IIF(InfoArray["MOUSE"], "", " not") +
                             " installed")
   @12,0 ?? FORMAT("W43,AC","Free XMS/EMS memory: " + STRVAL(InfoArray["EXTENDED"]) +
                     " / " + STRVAL(InfoArray["EXPANDED"]))

   PUSHBUTTON @14,16 WIDTH 10
      "OK"
      OK
      VALUE "OK"
      TAG "OKTag"
      TO AboutOK

ENDDIALOG

ENDPROC

WRITELIB LibName AboutBox
RELEASE PROCS AboutBox


;***********************************************************************;
;                             RepaintAboutBox()                         ;
; This procedure refreshes the time, date, and avail. memory listed in  ;
; the AboutBox() dialog box.                                            ;
;***********************************************************************;
PROC RepaintAboutBox(EventType, TagValue, EventValue, ElementValue)

REPAINTDIALOG

RETURN TRUE

ENDPROC

WRITELIB LibName RepaintAboutBox
RELEASE PROCS RepaintAboutBox


;***********************************************************************;
;                               ErrorBeep()                             ;
; This procedure merely beeps at the user using the value passed by the ;
; user.                                                                 ;
;***********************************************************************;
PROC ErrorBeep(tone)

SOUND tone 100

ENDPROC

WRITELIB LibName ErrorBeep
RELEASE PROCS ErrorBeep

;***********************************************************************;
;                                Shutdown()                             ;
; This procedure closes all open windows and table views, releases all  ;
; procedures from memory, and exits the program.                        ;
;***********************************************************************;
PROC Shutdown()

Message "Leaving the application..."    ; Tell user what's happening

IF SYSMODE() <> "Main"                  ; If table is open, make sure
   THEN DO_IT!                          ;  it's saved
ENDIF
ALTSPACE {Desktop} {Empty}              ; Clear desktop
RESET                                   ; Reset memory

IF ISTABLE("Answer") THEN DELETE "Answer" ENDIF
IF ISTABLE(TableDir + "ProData") THEN DELETE TableDir + "ProData" ENDIF
IF ISTABLE(TableDir + "TaxData") THEN DELETE TableDir + "TaxData" ENDIF
IF ISTABLE(TableDir + "LineUndo") THEN DELETE TableDir + "LineUndo" ENDIF

;quit "Replace this with EXIT in final program"  
EXIT
                                        ; Prompt to be removed later

ENDPROC

WRITELIB libname Shutdown               ; Writes procedure to UTIL.SC
RELEASE PROCS Shutdown                  ;  and releases it from memory


;***********************************************************************;
;                              MakeProposal()                           ;
; This procedure allows the user to print out a price list for a        ;
; certain category of parts and a certain price.                        ;
;***********************************************************************;
PROC MakeProposal()

PartDesc=""
PriceList="A"
CustNum=""

ButtonVal=False

WHILE ButtonVal<>True

HelpButtonVal=False

SHOWDIALOG "Proposal Data"
 @5,20 HEIGHT 11 WIDTH 40

@1,2 ?? "Part Dept:"
ACCEPT
 @1,13 WIDTH 24
 "A20"
 PICTURE "*20{[!]}"
 TO PartDesc

@3,2 ?? "Price List:"
ACCEPT
 @3,14 WIDTH 5
 "A1"
 PICTURE "[&]"
 TO PriceList

@5,2 ?? "Customer #:"
ACCEPT
 @5,14 WIDTH 20
 "N"
 TO CustNum

PUSHBUTTON @7,3 WIDTH 10
 "OK"
 OK
 DEFAULT
 VALUE TRUE
 TAG "OKButton"
 TO ButtonVal

PUSHBUTTON @7,15 WIDTH 10
 "Cancel"
 CANCEL
 VALUE FALSE
 TAG "CancelButton"
 TO ButtonVal

PUSHBUTTON @7,27 WIDTH 10
 "Help"
 OK
 VALUE True
 TAG "HelpButton"
 TO HelpButtonVal

ENDDIALOG

IF HelpButtonVal=True THEN HelpProposal() ENDIF

IF RetVal=FALSE THEN RETURN 1 ENDIF

ENDWHILE

PartDesc=UPPER(PartDesc)

IF ISBLANK(PartDesc) THEN
   MESSAGE "A parts description is required"
   RETURN 1
ENDIF

IF (NOT ISBLANK(CustNum)) AND (CustNum<>0) THEN
   VIEW TableDir+"Customer"
   MOVETO [Cust#]
   LOCATE CustNum
   IF RetVal=FALSE THEN
      MESSAGE "Customer #"+STRVAL(CustNum)+" does not exist!"
      RETURN 1
   ENDIF
   PriceList=[Price List]
   WINDOW CLOSE
ENDIF

IF ISBLANK(PriceList) OR (ASC(PriceList)>90 OR ASC(PriceList)<65) THEN
   MESSAGE "A valid price list code or a customer # is required"
   RETURN 1
ENDIF

Query

 Parts |     Part#      | Desc.             | Maker  | Price  | Cost  |
       | Check _PartNum | Check ~PartDesc.. | Check  | Check  | Check |

 Auxparts |  Part#   | PriceB | PriceC | PriceD | PriceE | 
          | _PartNum | Check  | Check  | Check  | Check  | 

 Auxparts | PriceF | PriceG | PriceH | PriceI | PriceJ | 
          | Check  | Check  | Check  | Check  | Check  | 

 Auxparts | PriceK | PriceL | PriceM | PriceN | PriceO | 
          | Check  | Check  | Check  | Check  | Check  | 

 Auxparts | PriceP | PriceQ | PriceR | PriceS | PriceT | 
          | Check  | Check  | Check  | Check  | Check  | 

 Auxparts | PriceU | PriceV | PriceW | PriceX | PriceY | 
          | Check  | Check  | Check  | Check  | Check  | 

 Auxparts | 
          | 

Endquery
DO_IT!

WINDOW HANDLE CURRENT TO TwhndAnswer
IF ISEMPTY("Answer") THEN
   DELETE "Answer"
   MESSAGE "There are no parts with the dept: " + PartDesc
   RETURN 1
ENDIF

SWITCH
   CASE PriceList="A" :
      FieldName="Price"
   CASE PriceList="Z" :
      FieldName="Cost"
   OTHERWISE :
      FieldName="Price"+PriceList
ENDSWITCH

CREATE TableDir + "Prodata" LIKE TableDir + "DummyPro"
COPYREPORT TableDir + "DummyPro" 1 "Prodata" "1"
COPYFORM TableDir + "DummyPro" 1 "Prodata" "1"
COEDIT TableDir + "Prodata"
WINDOW HANDLE CURRENT TO TwhndProdata

WINDOW SELECT TwhndAnswer
MOVETO FIELD FieldName

SCAN
   RecNum=RecNo()
   PartDesc=[Desc.]
   PartMaker=[Maker]
   PartNum=[Part#]
   Price=[]
   IF ISBLANK(Price) THEN Price=[Price] ENDIF
   WINDOW SELECT TwhndProdata
   MOVETO [Prodata->]
   IF NOT ISBLANK([Part #]) THEN
      END
      DOWN
   ENDIF
   [Part #]=PartNum
   [Desc.]=PartDesc
   [Maker]=PartMaker
   [Price]=Price
   WINDOW SELECT TwhndAnswer
   MOVETO RECORD RecNum
   MOVETO FIELD FieldName
ENDSCAN

DO_IT!
SORT "ProData" ON "Desc."
COEDITKEY

WINDOW HANDLE CURRENT TO TwhndProData
WINDOW SELECT TwhndProData
PICKFORM 1
WINDOW HANDLE FORM TO FwhndProData
MaxWindow(FwhndProData)

IMAGERIGHTS READONLY

HOME

GenericMenu()

WAIT WORKSPACE			; Allows user to wander on desktop
   PROC "GenericWaitProc"	; PROC that handles user events
   MESSAGE "MENUSELECT"		;  or a menu is chosen,
ENDWAIT				;  an event is passed to OrderWaitProc()

DO_IT!

PrintStatus=True

IF PrintSelect=True THEN
   SHOWMENU
      "File"		: "Print proposal to a file",
      "Printer"		: "Print prosal to the printer"
   TO PrintDest

   SWITCH
      CASE PrintDest="File" :
         ProFileName=GetFileName()
         IF ProFileName=False THEN
            MESSAGE "Print job cancelled"
            PrintStatus=False
            SLEEP 2000
         ENDIF

         IF ISFILE(ProFileName) THEN 
            IF ConfirmBox("File already exists. Delete?", "", "")=True THEN
               RUN NOREFRESH "Del "+STRVAL(ProFileName)
            ELSE
               MESSAGE "Print job cancelled"
               PrintStatus=False
               SLEEP 2000
            ENDIF
         ENDIF

         IF PrintStatus=True THEN
            ProFileName=ProFileName+"\013"
            Menu {Report} {Output} {ProData} {1} {File} TYPEIN ProFileName
         ENDIF

      CASE PrintDest="Printer" :
         MESSAGE "Printing Proposal..."
         REPORT TableDir + "ProData" "1"
         MESSAGE ""

      OTHERWISE :
         MESSAGE "Print job cancelled"
         SLEEP 2000

   ENDSWITCH
ELSE
   MESSAGE "Print job cancelled"
   SLEEP 2000
ENDIF

SHOWPULLDOWN ENDMENU		; Clear menu
PROMPT ""			; Clear prompt

CLEARALL
ECHO NORMAL
ECHO OFF


DELETE "Answer"
DELETE TableDir + "Prodata"

ENDPROC

WRITELIB LibName MakeProposal           ; Writes procedure to UTIL.SC
RELEASE PROCS MakeProposal              ;  and releases it from memory


;***********************************************************************;
;                               GetFileName()                           ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an part # in, an OK and a CANCEL buttons.                       ;
;***********************************************************************;
PROC GetFileName()
   PRIVATE FileName, ButtonVal    ; Local variable definiton

SHOWDIALOG "File Name" @ 6,20 HEIGHT 7 WIDTH 40 
				; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter File Name:"        ; Write label in box

   ACCEPT @ 1,20 WIDTH 15        ; Create an ACCEPT element
    "A11"                       ; Accept numeric
    PICTURE "*8{[&]}.*3{[&]}"		; Picure
    TAG "AcceptTag"             ; Unused
    TO FileName                   ; User's input put here

PUSHBUTTON @ 3,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 3,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE
   ELSE RETURN FileName
ENDIF
				; Return the number typed if exists, else
				;  return FALSE

ENDPROC

WRITELIB libname GetFileName      ; Writes procedure to CUSTOMER.LIB
RELEASE PROCS GetFileName         ;  and releases it from memory


;***********************************************************************;
;                           HelpMessagePart()                           ;
; This procedure pops up a dialog box that gives the user instructions  ;
; on how to do certain things.                                          ;
;***********************************************************************;
PROC HelpProposal()

SHOWDIALOG ""
 @1,10 HEIGHT 17 WIDTH 60

   @1,0 ?? FORMAT("W58,AC", "Help:")

   @3,3 ?? FORMAT("W58,AC", "To select a particular type of part:")
   @5,3 ?? "Move to the Part Dept field, type in the"
   @6,3 ?? "department you are looking for and add a '..' to the"
   @7,3 ?? "end of the description.  For example, 'OIL FILTER..'"
   @8,3 ?? "will locate all records with a department that starts"
   @9,3 ?? "with 'OIL FILTER', such as 'OIL FILTER',"
   @10,3 ??"'OIL FILTERS', or 'OIL FILTER-001'."
   
   PUSHBUTTON @13,25 WIDTH 10
      "OK"
      OK
      VALUE "OK"
      TAG "OKTag"
      TO AboutOK

ENDDIALOG

ENDPROC


WRITELIB LibName HelpProposal                                             ; Adds the procedure to the current library,
RELEASE PROCS HelpProposal                                                ;  and releases it from memory.


;***********************************************************************;
;                                GetPartNo()                            ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an part # in, an OK and a CANCEL buttons.                       ;
;***********************************************************************;
PROC GetPartNo()
   PRIVATE PartNo, ButtonVal    ; Local variable definiton

SHOWDIALOG "Part Number" @ 6,20 HEIGHT 7 WIDTH 40 
				; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter Part #:"        ; Write label in box

   ACCEPT @ 1,27 WIDTH 8        ; Create an ACCEPT element
    "A10"                       ; Accept numeric
    PICTURE "*!"		; Picure
    LOOKUP TableDir + "Parts"   ; Lookup response in Parts.DB
    TAG "AcceptTag"             ; Unused
    TO PartNo                   ; User's input put here

PUSHBUTTON @ 3,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 3,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE
   ELSE RETURN PartNo
ENDIF
				; Return the number typed if exists, else
				;  return FALSE

ENDPROC

WRITELIB libname GetPartNo      ; Writes procedure to CUSTOMER.LIB
RELEASE PROCS GetPartNo         ;  and releases it from memory


;***********************************************************************;
;                                 GetPrice()                            ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box to  ;
; enter an part # in, an OK and a CANCEL buttons.                       ;
;***********************************************************************;
PROC GetPrice()
   PRIVATE Price, ButtonVal    ; Local variable definiton

SHOWDIALOG "Part Price" @ 6,20 HEIGHT 7 WIDTH 40 
				; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter Price:"        ; Write label in box

   ACCEPT @ 1,27 WIDTH 8        ; Create an ACCEPT element
    "$"                         ; Accept numeric
    PICTURE "*!"		; Picure
    TAG "AcceptTag"             ; Unused
    TO Price                   ; User's input put here

PUSHBUTTON @ 3,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 3,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE
   ELSE RETURN Price
ENDIF
				; Return the number typed if exists, else
				;  return FALSE

ENDPROC

WRITELIB libname GetPrice      ; Writes procedure to CUSTOMER.LIB
RELEASE PROCS GetPrice         ;  and releases it from memory


;***********************************************************************;
;                              GetNewPartNo()                           ;
; This procedure opens a dialog box with 3 controls: an ACCCEPT box     ;
; without a lookup to enter an part # in, an OK and a CANCEL buttons.   ;
;***********************************************************************;
PROC GetNewPartNo()
   PRIVATE PartNo, ButtonVal    ; Local variable definiton

SHOWDIALOG "Part Number" @ 6,20 HEIGHT 7 WIDTH 40
				; Create a dialog box at 6,20 that's 7X40 big

@ 1,3 ?? "Enter Part #:"        ; Write label in box

   ACCEPT @ 1,27 WIDTH 8           ; Create an ACCEPT element
    "A10"                            ; Accept numeric
    PICTURE "*10{[!]}"		; Picure
    TAG "AcceptTag"                ; Unused
    TO PartNo                      ; User's input put here

PUSHBUTTON @ 3,6 WIDTH 10       ; Place button
 "OK"                           ; Button label
 OK                             ; Action of button when pressed
 DEFAULT                        ; This is the default button
 VALUE 1                        ; Value of button when pressed
 TAG "OKbutton"                 ; Unused
 TO ButtonVal                   ; Return user's button selection here

PUSHBUTTON @ 3,23 WIDTH 10      ; Place button
 "Cancel"                       ; Button label
 CANCEL                         ; Action of button when pressed
 VALUE 0                        ; Value of button when pressed
 TAG "Cancelbutton"             ; Unused
 TO ButtonVal                   ; Return user's button selection here

ENDDIALOG                       ; End dialog box construction

IF RetVal=FALSE THEN RETURN FALSE
   ELSE RETURN PartNo
ENDIF
				; Return the number typed if exists, else
				;  return FALSE

ENDPROC

WRITELIB libname GetNewPartNo      ; Writes procedure to CUSTOMER.LIB
RELEASE PROCS GetNewPartNo         ;  and releases it from memory


;***********************************************************************;
;                              CopyPriceList()                          ;
; This procedure allows the user to copy price lists from one list to   ;
; another.  (Ex:  Price List B to Price List C)                         ;
;***********************************************************************;
PROC CopyPriceList()

SourceList="B"								; Default value for SourceList
TargetList="B"								; Default value for SourceList

SHOWDIALOG "Price Lists" @ 6,20 HEIGHT 9 WIDTH 40			; Create a dialog box at 6,20 that's 9 X 40 big

@ 1,3 ?? "Source List:"							; Write label in box
ACCEPT @ 1,16 WIDTH 8							; Create an ACCEPT element
 "A1"									; Accept numeric
 PICTURE "&"								; Capitalize any letter entered
 MIN "B"								; "B" is the minimum letter that can be entered
 MAX "Y"								; "Y" is the maximum letter that can be entered
 TAG "Source"								; Dialog procedure handle
 TO SourceList								; Input value stored here

@ 3,3 ?? "Target List:"							; Write label in box
ACCEPT @ 3,16 WIDTH 8							; Create an ACCEPT element
 "A1"									; Accept numeric
 PICTURE "&"								; Capitalize any letter entered
 MIN "B"								; "B" is the minimum letter that can be entered
 MAX "Y"								; "Y" is the maximum letter that can be entered
 TAG "Target"								; Dialog procedure handle
 TO TargetList								; Input value stored here

PUSHBUTTON @ 5,6 WIDTH 10						; Place button
 "OK"									; Button label
 OK									; Action of button when pressed
 DEFAULT								; This is the default button
 VALUE 1								; Value of button when pressed
 TAG "OKbutton"								; Dialog procedure handle
 TO ButtonVal								; Button value stored here

PUSHBUTTON @ 5,23 WIDTH 10						; Place button
 "Cancel"								; Button label
 CANCEL									; Action of button when pressed
 VALUE 0								; Value of button when pressed
 TAG "Cancelbutton"							; Dialog procedure handle
 TO ButtonVal								; Button value stored here

ENDDIALOG								; End dialog box construction

IF RetVal=FALSE OR SourceList=TargetList THEN				; Return FALSE if the user cancels the dialog box or
   RETURN FALSE								;  if the source and target tables are the same
ENDIF

COEDIT TableDir + "AuxParts"						; Coedit the AuxParts table,
WINDOW HANDLE CURRENT TO TwhndAuxParts					;  store the handle,
WINDOW MOVE TwhndAuxParts TO 1000,0					;  and move it out of sight.

SCAN									; Do the following for every record:
   MOVETO FIELD "Price" + SourceList					;   Move to the source price field
   TempPrice=[]								;   Assign the price to TempPrice
   MOVETO FIELD "CommLevel" + SourceList				;   Move to the source commission level field
   TempCommLevel=[]							;   Assign the CommLevel to TempCommLevel

   MOVETO FIELD "Price" + TargetList					;   Move to the target price field
   []=TempPrice								;   Assign the current field the TempPrice
   MOVETO FIELD "CommLevel" + TargetList				;   Move to the target CommLevel field
   []=TempCommLevel							;   Assign the current field the TempCommLevel
ENDSCAN									; End scan loop

DO_IT!									; Save all changes

WINDOW SELECT TwhndAuxParts						; Select the AuxParts window
WINDOW CLOSE								; Close it

CLEARALL								; Clears the desktop,
ECHO NORMAL								;  and shows the user the changes
ECHO OFF

ENDPROC

WRITELIB LibName CopyPriceList						; Adds the procedure to the current library,
RELEASE PROCS CopyPriceList						;  and releases it from memory.

;***********************************************************************;
;                              GenericMenu()                            ;
; This procedure handles user interaction while viewing the settlement  ;
; form.                                                                 ;
;***********************************************************************;
PROC GenericMenu()
SHOWPULLDOWN
   ""          : "About application"                   : "AboutBox",
   "Print"      : "Print report"                        : "PrintReport",
   "Cancel"     : "Cancel the current invoice"          : "CancelMenu"
      SUBMENU
      "No"      : "Do not cancel the current invoice"   : "NoCancel",
      "Yes"     : "Cancel the current invoice"          : "Cancel"
      ENDSUBMENU
ENDMENU

ENDPROC

WRITELIB libname GenericMenu      ; Writes procedure to UTIL.SC
RELEASE PROCS GenericMenu         ;  and releases it from memory


;***********************************************************************;
;                             GenericWaitProc()                         ;
; This procedure handles user interaction while viewing the settlement  ;
; form.                                                                 ;
;***********************************************************************;
PROC GenericWaitProc(EventType, EventRecord, CycleNumber)
SWITCH

   CASE EventRecord["TYPE"]="MESSAGE" :
   SWITCH
      CASE EventRecord["MenuTag"]="AboutBox" :
         AboutBox()
      RETURN 1

      CASE EventRecord["MenuTag"]="PrintReport" :
         IF CheckPrinter() THEN
            PrintSelect=True
            RETURN 2
         ELSE
            MESSAGE "Print job cancelled"
            RETURN 1
         ENDIF
      RETURN 0

      CASE EventRecord["MenuTag"]="NoCancel" :
      RETURN 1

      CASE EventRecord["MenuTag"]="Cancel" :
         PrintSelect=False
      RETURN 2
   ENDSWITCH
ENDSWITCH

ENDPROC

WRITELIB libname GenericWaitProc      ; Writes procedure to UTIL.SC
RELEASE PROCS GenericWaitProc         ;  and releases it from memory


;***********************************************************************;
;                              ClearPriceList()                         ;
;***********************************************************************;
PROC ClearPriceList()

PriceList="B"								; Default value for PriceList

SHOWDIALOG "Price Lists" @ 6,20 HEIGHT 7 WIDTH 40			; Create a dialog box at 6,20 that's 9 X 40 big

@ 1,3 ?? "List to Clear:"						; Write label in box
ACCEPT @ 1,19 WIDTH 8							; Create an ACCEPT element
 "A1"									; Accept numeric
 PICTURE "&"								; Capitalize any letter entered
 MIN "B"								; "B" is the minimum letter that can be entered
 MAX "Y"								; "Y" is the maximum letter that can be entered
 TAG "PriceList"							; Dialog procedure handle
 TO PriceList								; Input value stored here

PUSHBUTTON @ 3,6 WIDTH 10						; Place button
 "OK"									; Button label
 OK									; Action of button when pressed
 DEFAULT								; This is the default button
 VALUE 1								; Value of button when pressed
 TAG "OKbutton"								; Dialog procedure handle
 TO ButtonVal								; Button value stored here

PUSHBUTTON @ 3,23 WIDTH 10						; Place button
 "Cancel"								; Button label
 CANCEL									; Action of button when pressed
 VALUE 0								; Value of button when pressed
 TAG "Cancelbutton"							; Dialog procedure handle
 TO ButtonVal								; Button value stored here

ENDDIALOG								; End dialog box construction

IF RetVal=FALSE THEN							; Return FALSE if the user cancels the dialog box or
   RETURN FALSE								;  if the source and target tables are the same
ENDIF

VIEW TableDir+"AuxParts"
WINDOW HANDLE CURRENT TO TwhndAuxParts
WINDOW MOVE TwhndAuxParts TO 1000,0

MOVETO [AuxParts->]
HOME

COEDITKEY

SCAN
MOVETO FIELD "Price"+STRVAL(PriceList)
[]=BLANKNUM()
MOVETO FIELD "CommLevel"+STRVAL(PriceList)
[]=""
ENDSCAN

DO_IT!
CLEARALL

ENDPROC

WRITELIB libname ClearPriceList      ; Writes procedure to UTIL.SC
RELEASE PROCS ClearPriceList         ;  and releases it from memory
